##  Resources
Learn about the benefits of using SAP LeanIX for ERP transformations from customer stories:
  * [Travis Perkins | SAP S/4HANA-Transformation![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fen%2Fcustomers%2Fsuccess-stories%2Ftravis-perkins "https://www.leanix.net/en/customers/success-stories/travis-perkins"): Find out how SAP LeanIX helped a customer prepare for its transformation and also fostered collaboration
  * [Marc O'Polo | SAP S/4HANA-Transformation![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fen%2Fcustomers%2Fsuccess-stories%2Fmarc-o-polo "https://www.leanix.net/en/customers/success-stories/marc-o-polo"): Learn how a customer established visibility and transparency of the current IT landscape with SAP LeanIX, but also a view of the target state after transformation.


To learn how SAP LeanIX Architecture and Road Map Planning helps companies shift operational models, refer to the [Business Transformation Management Playbook![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fen%2Fdownload%2Fbusiness-transformation-management-playbook "https://www.leanix.net/en/download/business-transformation-management-playbook").
